<?php

namespace Litecms\Blacklist\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Blacklist\Models\Blacklist;

class BlacklistPolicy
{

    /**
     * Determine if the given user can view the blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Blacklist $blacklist)
    {
        if ($user->canDo('blacklist.blacklist.view') && $user->isAdmin()) {
            return true;
        }

        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blacklist.blacklist.create');
    }

    /**
     * Determine if the given user can update the given blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Blacklist $blacklist)
    {
        if ($user->canDo('blacklist.blacklist.edit') && $user->isAdmin()) {
            return true;
        }

        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Blacklist $blacklist)
    {
        return $blacklist->user_id == user_id() && $blacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Blacklist $blacklist)
    {
        if ($user->canDo('blacklist.blacklist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blacklist.
     *
     * @param UserPolicy $user
     * @param Blacklist $blacklist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Blacklist $blacklist)
    {
        if ($user->canDo('blacklist.blacklist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
