<?php

namespace Litecms\Blacklist\Providers;

use Illuminate\Support\ServiceProvider;

class BlacklistServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'blacklist');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'blacklist');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.blacklist', function ($app) {
            return $this->app->make('Litecms\Blacklist\Blacklist');
        });

                // Bind Blacklist to repository
        $this->app->bind(
            'Litecms\Blacklist\Interfaces\BlacklistRepositoryInterface',
            \Litecms\Blacklist\Repositories\Eloquent\BlacklistRepository::class
        );

        $this->app->register(\Litecms\Blacklist\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Blacklist\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Blacklist\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.blacklist'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/blacklist.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/blacklist')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/blacklist')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
